﻿using System;
using System.Text;
using System.Security.Cryptography;
using System.Net;
using System.IO;

namespace FredTest1 {

    public class AnnotateAPI {

        //Api Configuration
        private readonly static String protocol = "http://";
        private readonly static String host = "192.168.1.123/";
        private readonly static String annotatePath = "sample/php/";
        private readonly static String errorloc = "http://mysite.org/error.php";
        private readonly static String apiUser = "fred@textensor.com";
        private readonly static String apiKey = "....";
        private readonly static long validfor = 60 * 60 * 24 * 30 * 3; //seconds
        
        public static String LoginAs(String annotateUser, String targetPage, String workspace) {
            StringBuilder sb = new StringBuilder();

            sb.Append(AnnotateAPI.signRequestURL(protocol + host + annotatePath, 
                                    "loginAs.php",
                                    apiUser,
                                    apiKey,
                                    annotateUser,
                                    validfor));
            sb.Append("&errloc=" + errorloc);
            sb.Append("&remember=0");

            if (targetPage != null) {
                sb.Append("&loc=" + targetPage+"?ws="+workspace);
            } else {
              sb.Append("&loc=annotateHome.php");  
            }
            //if (workspace != null) { sb.Append("&ws=" + workspace); }
            
            return sb.ToString();
        }

        public static String ListDocuments(String annotateUser, String workspace, String from, String to, Boolean withMeta) {
            StringBuilder sb = new StringBuilder();
            sb.Append(AnnotateAPI.signRequestURL(protocol + host + annotatePath,
                                    "listDocuments.php",
                                    apiUser,
                                    apiKey,
                                    annotateUser,
                                    validfor));
            sb.Append("&ws=" + workspace);
            sb.Append("&from=" + from);
            sb.Append("&to=" + to);
            sb.Append("&withmeta=" + (withMeta ? 1 : 0));
            return sb.ToString();
        }

        public static String FetchURL(String url)
        {
            String strResult;
            WebResponse objResponse;
            WebRequest objRequest = HttpWebRequest.Create(url);
            objResponse = objRequest.GetResponse();
            using (StreamReader sr = new StreamReader(objResponse.GetResponseStream()))
            {
                strResult = sr.ReadToEnd();
                sr.Close();
            }
            return strResult;
        }

        public static String ListTranscripts(String annotateUser, String workspace)
        {
            StringBuilder sb = new StringBuilder();
            sb.Append(AnnotateAPI.signRequestURL(protocol + host + annotatePath,
                                    "apiListTranscripts.php",
                                    apiUser,
                                    apiKey,
                                    annotateUser,
                                    validfor));
            sb.Append("&ws=" + workspace);
            return sb.ToString();
        }

        protected static String signRequestURL(String host,
                                            String apiEndPoint,
                                            String apiUser,
                                            String apiKey,
                                            String annotateUser,
                                            long validfor) {
            StringBuilder sb = new StringBuilder();

            sb.Append(host);
            sb.Append(apiEndPoint);
            sb.Append("?");
            String endpointAccessString = signRequest(apiEndPoint, apiUser, apiKey, annotateUser, validfor);
            sb.Append(endpointAccessString);
            return sb.ToString();
         }

       private static String signRequest(String apiEndPoint,
                                        String apiUser,
                                        String apiKey,
                                        String annotateUser,
                                        long validfor) {
           long requesttime = getCurrentUnixTime() + validfor; //in seconds
           StringBuilder stringToSign = new StringBuilder();
           stringToSign.Append(apiEndPoint + "\n");
           stringToSign.Append(apiUser + "\n");
           stringToSign.Append(requesttime + "\n");
           stringToSign.Append(annotateUser);


           String signature = sign(apiKey, stringToSign.ToString());

           return "api-user=" + urlSafeString(apiUser) +
                  "&api-requesttime=" + urlSafeString(requesttime.ToString()) +
                  "&api-annotateuser=" + urlSafeString(annotateUser) +
                  "&api-auth=" + urlSafeString(signature);
       }

        private static String sign(String apiKey, String input) {
            byte[] apiKeyByteArray = Encoding.ASCII.GetBytes(apiKey);
            byte[] inputByteArray = Encoding.ASCII.GetBytes(input);
            HMACSHA1 myhmacsha1 = new HMACSHA1(apiKeyByteArray);
            byte[] hashByteArray = myhmacsha1.ComputeHash(inputByteArray);
            return Convert.ToBase64String(hashByteArray);//.Replace("\n","");
        }

        private static long getCurrentUnixTime() {
            TimeSpan t = (DateTime.UtcNow - new DateTime(1970, 1, 1, 0, 0, 0, 0));
            return ((long)t.TotalSeconds);
        }

        private static String urlSafeString(String input) {
            var utf8 = System.Text.Encoding.UTF8;
            return System.Uri.EscapeDataString(utf8.GetString(utf8.GetBytes(input)));
        }
    }
}