<?php

  //
  // Test logging in to annotate as a given user.
  //

require_once("annotateApi.php");
require_once("test_config.php");

// Make a login link for given $user email, then redirect
// to $loc. If there is a problem, go to $errloc instead.
//
function makeLoginLink($user, $loc, $errloc, $create="", $sig="", $licensed="",
                       $firstname="", $lastname="", $add="", $ws="", $role="") {
  global $annotateServer, $apiuser, $apikey;

  $phpfn = "loginAs.php";

  $annotateuser = $user; // e.g. "joe3@textensor.com";

  $validfor = 60 * 30; // Make this request valid for 30 mins.

  $request = signRequest($phpfn, $apiuser, $apikey, $annotateuser, $validfor);
  $url = "$annotateServer/php/$phpfn?$request";

  // After login, display the document list:
  // $loc = "documents.php?ws=$sampleWS""; // the list of documents in a workspace

  // Possible alternative pages to display after login:
  // $loc = "workspaces.php";  // the list of workspaces
  // $loc = "account.php";     // the account page
  // $loc = "notes.php?ws=$sampleWS";                    // the notes index
  // $loc = "pdfnotate.php?d=$sampleDate&c=$sampleCode"; // to login and jump to a document.

  $url .= "&loc=".rawurlencode($loc);

  // On login error - go to this URL and set ?msg={error message}
  // $errloc = "../api/html_error.php";
  $url .= "&errloc=".rawurlencode($errloc);

  // Store the password + username in a cookie:
  $url .= "&remember=1"; 
  // If you don't want to store the login info in the browser cookie, change to:
  // $url .= "&remember=0"; 
      
  if ($create) {
    $url .= "&create=1";
    if ($sig) {
      $url .= "&sig=".rawurlencode($sig);
    }
    if ($licensed) {
      $url .= "&licensed=1";
    }
    if ($firstname) {
      $url .= "&firstname=".rawurlencode($firstname);
    }
    if ($lastname) {
      $url .= "&lastname=".rawurlencode($lastname);
    }  
  }
  
  if ($add) {
    $url .= "&add=1";
    if ($ws) {
      $url .= "&ws=".$ws;
    }
    if ($role) {
      $url .= "&role=".$role;
    }
  }

  return $url;
}



?>
<!doctype html>
<html>
<body>
<h3>Auto-logging in users to their Annotate account</h3>

<?php

// If something goes wrong with the link, redirect to an error page:
$errloc = $annotateServer."/api/html_error.php";

$login1 = makeLoginLink( $sampleUser, "workspaces.php", $errloc );
$login2 = makeLoginLink( $sampleUser2, "workspaces.php", $errloc );
$login3 = makeLoginLink( $sampleUser, "notes.php", $errloc );
$login4 = makeLoginLink( $sampleUser2, "pdfnotate.php?d=$sampleDate&c=$sampleCode", $errloc, 0, "", "", "", "", 1, $sampleWS, $sampleRole );
$login5 = makeLoginLink( $sampleUser2, "pdfnotate.php?d=$sampleDate&c=$sampleCode", $errloc, 0, "", "", "", "", 1, $sampleWS, $sampleRole );


$random = rand(100, 1000);
$newuser = "newuser" . $random."@example.com";
$login6 = makeLoginLink( $newuser, "workspaces.php", $errloc, 1, "", false, "new", "user$random" );

$licenseduser = "licenseduser" . $random."@example.com";
$login7 = makeLoginLink( $licenseduser, "workspaces.php", $errloc, 1, "", 1, "new", "licenseduser$random" );
//$random = 317;
$mixeduser = "Mixed.User" . $random."@example.com";
$login8 = makeLoginLink( $mixeduser, "workspaces.php", $errloc, 1, "", 1, "new", "user" );

print "<h4>Logging in as the given user</h4>";

print "<p><a target='_blank' href='".$login1."'>Click to log in as $sampleUser and view workspaces list</a></p>";
print "<p><a target='_blank' href='".$login2."'>Click to log in as $sampleUser2 and view workspaces list</a></p>";
//print "<p><a target='_blank' href='".$login3."'>Click to log in as $sampleUser and view notes index</a></p>";

print "<h4>Logging in as the given user, and creating a new account for them if necessary</h4>";

//print "<p><a target='_blank' href='".$login6."'>Click to create new account for $newuser (if needed) and view their workspaces page</a></p>";
print "<p><a target='_blank' href='".$login7."'>Click to create new account for $licenseduser (if needed, license them to upload new documents) and view their workspaces page</a></p>";

//print "<p><a target='_blank' href='".$login8."'>Click to create new account for $mixeduser (if needed, license them to upload new documents) and view their workspaces page</a></p>";

?>
<h4>Logging in as a user, adding user to a workspace if necessary and viewing a document within it</h4>
<p>
<em>[note - the links below will only work once you've edited the sampleDate, sampleCode, sampleWS and sampleRole settings in the test config file]</em>
</p>

<?php

print "<p><a target='_blank' href='".$login4."'>Click to log in as $sampleUser2, add to workspace $sampleWS with role $sampleRole and view document $sampleDate $sampleCode</a> in a new window </p>";
print "<p><a target='iframeid' href='".$login5."'>Click to log in as $sampleUser2, add to workspace $sampleWS with role $sampleRole and show document $sampleDate $sampleCode</a> in the iframe:</p>";


?>


<iframe src='about:blank' style='border:1px solid blue' width='100%' height='500px' id='iframeid' name='iframeid' >
</iframe>

</body>
</html>
