<?php

  //
  // Simple tutorial to demonstrate the basic API actions
  //

require_once("annotateApi.php");

// Make a POST request to Annotate
function makePOST($phpfn, $params) {
  global $annotateServer, $apiuser, $apikey; // these need to be supplied in test_config.php, see test_config-sample.php
  
  $annotateuser = $apiuser; // for the purpose of this example
  $request = signRequest($phpfn, $apiuser, $apikey, $annotateuser);
  $url = "$annotateServer/php/$phpfn?$request";
  
  $postdata = http_build_query($params);
  $context = stream_context_create(
      array('http' =>
          array('method' => 'POST',
              'header' => "Content-type: application/x-www-form-urlencoded\r\n".
              "Content-Length: " . strlen($postdata) . "\r\n",
              'content' => $postdata
          )
      )
  );
  
  print "The request is: $url\n";
  print "POST params:\n";
  print_r($params);
  
  $ret = file_get_contents($url, false, $context);
  return $ret;
}

// Step 1: Create a workspace
$phpfn = "apiCreateWorkspace.php";
$params = array(
    "name" => "Test workspace",
);

print "Step 1: Create a workspace owned by $apiuser\n\n";
$ret = makePOST($phpfn, $params);

if (substr($ret, 0, 3) == "ERR") {
  print "Returned error: $ret\n";
  exit;
}
print "Server response is: $ret\n";

$retbits = explode(" ", $ret);
if (isset($retbits[1])) {
  $ws = $retbits[1];
}

// Step 2: Upload a document
$phpfn = "uploadDocument.php";
$params = array(
    "ws" => $ws,
    "urlfilename" => "sample.pdf",
    "url" => "http://www.textensor.com/enhancing-documents-2007.pdf"
    
);

print "\nStep 2: Upload a document to the newly create workspace $ws\n\n";
$ret = makePOST($phpfn, $params);

if (substr($ret, 0, 3) == "ERR") {
  print "Returned error: $ret\n";
  exit;
}
print "Server response is: $ret\n";

$retbits = explode(" ", $ret);
if ((isset($retbits[1])) && (isset($retbits[2]))) {
  $date = $retbits[1];
  $code = $retbits[2];
}

// Step 3: Create a new user account
$phpfn = "createAccount.php";
$random = rand(100, 1000);
$newuser = "user$random@example.com";
$request = signRequest($phpfn, $apiuser, $apikey, $newuser);
$url = "$annotateServer/php/$phpfn?$request";

print "\nStep 3: Create a new user account\n\n";
print "The request is: $url\n";
$ret = file_get_contents($url);

if (substr($ret, 0, 3) == "ERR") {
  print "Returned error: $ret\n";
  exit;
}
print "Server response is: $ret\n";

// Step 4: Add the newly created user account to the workspace
$phpfn = "apiUpdateWorkspaceUsers.php";
$params = array(
    "ws" => $ws,
    "action" => "add",
    "email" => $newuser,
    "roleid" => "3"
);

print "\nStep 4: Add $newuser to the workspace $ws\n\n";
$ret = makePOST($phpfn, $params);

if (substr($ret, 0, 3) == "ERR") {
  print "Returned error: $ret\n";
  exit;
}
print "Server response is: $ret\n";
print "Use loginAs.php with loc='pdfnotate.php?d=$date&c=$code' to log the user in and display the document. Steps 3 and 4 can also be done on the fly through loginAs.php\n";
?>